
#include "client.h"
#include <qsocket.h>
#include <qtextstream.h>


Client::Client( Q_UINT16 port, QObject * parent, const char * name ) 
	: QObject(parent,name)
{
	// create the socket and connect various of its signals
	socket = new QSocket( this );
	connect( socket, SIGNAL(connected()),
	         SLOT(socketConnected()) );
	connect( socket, SIGNAL(connectionClosed()),
	         SLOT(socketConnectionClosed()) );
	connect( socket, SIGNAL(readyRead()),
	         SLOT(socketReadyRead()) );
	connect( socket, SIGNAL(error(int)),
	         SLOT(socketError(int)) );

	// connect to the server
	qDebug("Client::Client: trying to connect to the server");
	socket->connectToHost( "localhost", port );
}

Client::~Client() {
}

void Client::closeConnection() {
	socket->close();
	if ( socket->state() == QSocket::Closing ) {
		// We have a delayed close.
		connect( socket, SIGNAL(delayedCloseFinished()),
	             SLOT(socketClosed()) );
	} else {
		// The socket is closed.
		socketClosed();
	}
}

void Client::sendToServer(QString text) {
	qDebug("Client::sendToServer: '%s'", text.utf8().data());
	// write to the server
	QTextStream os(socket);
	os << text << "\n";
}

void Client::socketReadyRead() {
	// read from the server
	while ( socket->canReadLine() ) {
		// In Qt 4 readline doesn't return a QString
		QString s( socket->readLine() ); 
		qDebug("Client::socketReadyRead: '%s'", s.utf8().data() );

		if (s.startsWith("I'm smplayer too, go on")) {
			qDebug(" * Identified server!");
			emit serverIdentified();
		} else {
			emit receivedUnknownText(s);
		}
	}
}

void Client::socketConnected() {
	qDebug("Client::socketConnected: connected to server");
	emit connected();

	sendToServer("Hello, this is smplayer");
}

void Client::socketConnectionClosed() {
	qDebug("Client::socketConnectionClosed: connection closed by the server");
}

void Client::socketClosed() {
	qDebug("Client::socketClosed: connection closed");
	emit connectionClosed();
}

void Client::socketError( int e ) {
	qDebug("Client::socketError: error number %d occurred", e);
	if ( (e == QSocket::ErrHostNotFound) ||
         (e == QSocket::ErrConnectionRefused) ) 
	{
		emit notConnected();
	}
}
