
#include "server.h"
#include <qtextstream.h>
#include <qregexp.h>

ClientSocket::ClientSocket( int sock, QObject *parent, const char *name ) 
	: QSocket( parent, name )
{
	connect( this, SIGNAL(readyRead()), SLOT(readClient()) );
	connect( this, SIGNAL(connectionClosed()), SLOT(deleteLater()) );
	setSocket( sock );
}

ClientSocket::~ClientSocket() {
}

void ClientSocket::readClient() {
	QTextStream ts( this );
	while ( canReadLine() ) {
		QString str = ts.readLine();
		qDebug("ClientSocket::readClient: '%s'", str.utf8().data() );

		if (str.startsWith("Hello, this is smplayer")) {
			sendText("I'm smplayer too, go on");
		} 
		else {
			QRegExp rx("^open (.*)");
			if (rx.search(str) > -1) {
				QString file = rx.cap(1);
				qDebug(" * asked to open '%s'", file.utf8().data());
				emit receivedOpen(file);
			} 
		}
	}
}

void ClientSocket::sendText(QString text) {
	QTextStream os(this);
	os << text << "\n";
}

Server::Server( Q_UINT16 port, QObject* parent ) 
	: QServerSocket( port, 1, parent )
{
	if ( !ok() ) {
		qWarning("Server::Server: failed to bind to port %d", port);
	} else {
		qDebug("Server::Server:: server started at port %d", port);
	}
}

Server::~Server() {
}

void Server::newConnection( int socket ) {
	ClientSocket *s = new ClientSocket( socket, this );
	connect(s, SIGNAL(receivedOpen(QString)), 
            this, SLOT(gotOpenCommand(QString)));
	emit newConnect( s );
}

void Server::gotOpenCommand(QString text) {
	emit receivedOpen(text);
}

